@@ -1,5 +1,5 @@
 function loader() {
-  return 'a { color: red };';
+  return "a { color: red };";
 }
 
 module.exports = loader;
