@@ -26,6 +26,33 @@ describe("loader", () => {
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
 
+  it("should work with `templateLiteral` support", async () => {
+    const compiler = getCompiler(
+      "./basic.js",
+      {},
+      {
+        output: {
+          path: path.resolve(__dirname, "./outputs"),
+          filename: "[name].bundle.js",
+          chunkFilename: "[name].chunk.js",
+          publicPath: "/webpack/public/path/",
+          assetModuleFilename: "[name][ext]",
+          environment: {
+            templateLiteral: true,
+          },
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(getModuleSource("./basic.css", stats)).toMatchSnapshot("module");
+    expect(getExecutedCode("main.bundle.js", compiler, stats)).toMatchSnapshot(
+      "result"
+    );
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
   it("should work in 'production' mode", async () => {
     const compiler = getCompiler(
       "./basic.js",
@@ -245,7 +272,7 @@ describe("loader", () => {
     );
     const stats = await compile(compiler);
 
-    expect(stats.compilation.modules.size).toBe(14);
+    expect(stats.compilation.modules.size).toBe(13);
     expect(getWarnings(stats)).toMatchSnapshot("warnings");
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
@@ -274,7 +301,7 @@ describe("loader", () => {
     );
     const stats = await compile(compiler);
 
-    expect(stats.compilation.modules.size).toBe(14);
+    expect(stats.compilation.modules.size).toBe(13);
     expect(getWarnings(stats)).toMatchSnapshot("warnings");
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
@@ -303,7 +330,7 @@ describe("loader", () => {
     );
     const stats = await compile(compiler);
 
-    expect(stats.compilation.modules.size).toBe(13);
+    expect(stats.compilation.modules.size).toBe(12);
     expect(getWarnings(stats)).toMatchSnapshot("warnings");
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
@@ -548,4 +575,75 @@ describe("loader", () => {
     expect(getWarnings(stats)).toMatchSnapshot("warnings");
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
+
+  it("should work and nothing to do with built-in CSS support", async () => {
+    const compiler = getCompiler(
+      "./basic-built-in-css-support.js",
+      {},
+      {
+        experiments: {
+          css: true,
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(getModuleSource("./basic.css", stats)).toMatchSnapshot("module");
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
+  it("should work and nothing to do with built-in CSS support", async () => {
+    const compiler = getCompiler(
+      "./basic-built-in-css-support.js",
+      {},
+      {
+        experiments: {
+          futureDefaults: true,
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(getModuleSource("./basic.css", stats)).toMatchSnapshot("module");
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
+  it("should work with built-in CSS support", async () => {
+    const compiler = getCompiler(
+      "./basic.js",
+      {},
+      {
+        experiments: {
+          css: true,
+        },
+        module: {
+          rules: [
+            {
+              type: "javascript/auto",
+              test: /\.(mycss|css)$/i,
+              use: [
+                {
+                  loader: path.resolve(__dirname, "../src"),
+                },
+              ],
+            },
+            {
+              test: /\.(png|jpg|gif|svg|eot|ttf|woff|woff2)$/i,
+              type: "asset/resource",
+            },
+          ],
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(getModuleSource("./basic.css", stats)).toMatchSnapshot("module");
+    expect(getExecutedCode("main.bundle.js", compiler, stats)).toMatchSnapshot(
+      "result"
+    );
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
 });
