@@ -1053,7 +1053,7 @@ describe('"modules" option', () => {
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
 
-  it("should work with the 'auto' and exctract CSS using mini-css-extract-plugin", async () => {
+  it("should work with the 'auto' and extract CSS using mini-css-extract-plugin", async () => {
     const compiler = getCompiler(
       "./modules/mode/modules.js",
       {},
@@ -1854,6 +1854,39 @@ describe('"modules" option', () => {
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
 
+  it('should work with "url", "namedExport" and "templateLiteral" support', async () => {
+    const compiler = getCompiler(
+      "./modules/url/source.js",
+      {
+        modules: {
+          namedExport: true,
+        },
+      },
+      {
+        output: {
+          path: path.resolve(__dirname, "./outputs"),
+          filename: "[name].bundle.js",
+          chunkFilename: "[name].chunk.js",
+          publicPath: "/webpack/public/path/",
+          assetModuleFilename: "[name][ext]",
+          environment: {
+            templateLiteral: true,
+          },
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(getModuleSource("./modules/url/source.css", stats)).toMatchSnapshot(
+      "module"
+    );
+    expect(getExecutedCode("main.bundle.js", compiler, stats)).toMatchSnapshot(
+      "result"
+    );
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
   it('should work with "url"', async () => {
     const compiler = getCompiler("./modules/url/source.js", {
       modules: true,
@@ -1961,6 +1994,40 @@ describe('"modules" option', () => {
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
 
+  it('show work with the "mode: icss", "exportOnlyLocals" options and "templateLiteral" support', async () => {
+    const compiler = getCompiler(
+      "./modules/icss/tests-cases/import/source.js",
+      {
+        modules: {
+          mode: "icss",
+          exportOnlyLocals: true,
+        },
+      },
+      {
+        output: {
+          path: path.resolve(__dirname, "./outputs"),
+          filename: "[name].bundle.js",
+          chunkFilename: "[name].chunk.js",
+          publicPath: "/webpack/public/path/",
+          assetModuleFilename: "[name][ext]",
+          environment: {
+            templateLiteral: true,
+          },
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(
+      getModuleSource("./modules/icss/tests-cases/import/source.css", stats)
+    ).toMatchSnapshot("module");
+    expect(getExecutedCode("main.bundle.js", compiler, stats)).toMatchSnapshot(
+      "result"
+    );
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
   it('show work with the "mode: icss" and "namedExport" options', async () => {
     const compiler = getCompiler(
       "./modules/icss/tests-cases/import/source.js",
@@ -2001,6 +2068,39 @@ describe('"modules" option', () => {
     expect(getErrors(stats)).toMatchSnapshot("errors");
   });
 
+  it('show work with the "mode" option using the "local" value and "templateLiteral" support', async () => {
+    const compiler = getCompiler(
+      "./modules/composes/composes.js",
+      {
+        modules: {
+          mode: "local",
+        },
+      },
+      {
+        output: {
+          path: path.resolve(__dirname, "./outputs"),
+          filename: "[name].bundle.js",
+          chunkFilename: "[name].chunk.js",
+          publicPath: "/webpack/public/path/",
+          assetModuleFilename: "[name][ext]",
+          environment: {
+            templateLiteral: true,
+          },
+        },
+      }
+    );
+    const stats = await compile(compiler);
+
+    expect(
+      getModuleSource("./modules/composes/composes.css", stats)
+    ).toMatchSnapshot("module");
+    expect(getExecutedCode("main.bundle.js", compiler, stats)).toMatchSnapshot(
+      "result"
+    );
+    expect(getWarnings(stats)).toMatchSnapshot("warnings");
+    expect(getErrors(stats)).toMatchSnapshot("errors");
+  });
+
   it("should emit warning when localIdentName is emoji", async () => {
     const compiler = getCompiler("./modules/pure/pure.js", {
       modules: {
